exceptiontools.DurationError
============================

.. abjad-lineage:: abjad.tools.exceptiontools.DurationError.DurationError

.. autoclass:: abjad.tools.exceptiontools.DurationError.DurationError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.DurationError.DurationError.__unicode__
   :noindex:
